@@ -11,6 +11,7 @@ class Entity(object):
     def __init__(self, data):
         self._data = data
         self.validator = Validator(self.schema) 
+        self.validation_errors = {}
 
 
     def validate(self):
@@ -18,13 +19,17 @@ class Entity(object):
         Validate methods for the entity based on its
         internal schema (see tests for example)
         """
-        
-        return self.validator.validate(self._get_relevant_data())
+        valid = self.validator.validate(self._get_relevant_data())
+        self.validation_errors = self.validator.errors
+        return valid
 
     def _get_relevant_data(self):
         data = {}
         for k in self.schema.keys():
-            data[k] = self._data[k] 
+            try:
+                data[k] = self._data[k] 
+            except KeyError:
+                pass
 
         return data
 
